package checkers.interned;

import checkers.basetype.*;
import checkers.interned.quals.Interned;
import checkers.metaquals.TypeQualifiers;
import checkers.source.*;

import javax.annotation.processing.*;
import javax.lang.model.*;

/**
 * A typechecker plug-in for the {@link checkers.interned.quals.Interned} qualifier that
 * finds (and verifies the absence of) equality-testing and interning errors.
 *
 * <p>
 *
 * The {@link checkers.interned.quals.Interned} annotation indicates that a variable
 * refers to the canonical instance of an object, meaning that it is safe to
 * compare that object using the "==" operator. This plugin warns whenever
 * "==" is used in cases where one or both operands are not
 * {@link checkers.interned.quals.Interned}.  Optionally, it suggests using "=="
 * instead of ".equals" where possible.
 *
 * @manual #interned Interned checker
 */
@TypeQualifiers({ Interned.class })
@SupportedLintOptions({"dotequals", "flow"})
@SupportedSourceVersion(SourceVersion.RELEASE_7)
public final class InternedChecker extends BaseTypeChecker { }
